@@ -1,3 +1,6 @@
 from collections import Counter
 data = [1,1,3,2,3,5]
-x = Counter(data)
\ No newline at end of file
+x = Counter(data)
+y = '12334123'
+z = '324'
+print(z in y)
\ No newline at end of file
