@@ -88,9 +88,17 @@ def get_keyword_graph(
     :param score_positive: 正向情感加分
     :return: 节点表，边表，附加信息
     """
+    tfidf = jieba.analyse.TFIDF()
     if default_keyword:
         # 使用预先计算好的keyword（从1000万个视频标题文本计算得到）
-        keyword2score = load_pickle(path.join(DATAPATH, 'keyword.pkl'))
+        keyword2score_all = load_pickle(path.join(DATAPATH, 'keyword.pkl'))
+        meet_word = set()
+        for sentence in tqdm(texts, 'select default keyword'):
+            meet_word |= set(list(tfidf.tokenizer.cut(sentence)))
+        keyword2score = {}
+        for k, v in keyword2score_all.items():
+            if k in meet_word:
+                keyword2score[k] = v
     else:
         # 不使用预先计算好的keyword
         if deduplication:
@@ -119,7 +127,6 @@ def get_keyword_graph(
     keypair2fragment = defaultdict(list)
     keypair2sentence = defaultdict(list)
     keypair_score_sum = defaultdict(int)
-    tfidf = jieba.analyse.TFIDF()
     for sentence in tqdm(texts, 'connect keypair'):
         sp = list(tfidf.tokenizer.cut(sentence))
         sp_pos = [[sp[i], len(''.join(sp[:i]))] for i in range(len(sp))]
@@ -293,7 +300,8 @@ class SentenceKeyword:
                 continue
             rst.append(fragment)
         if use_label:
-            rst = list(set(rst.extend([_ for _ in label if len(_)>3])))
+            rst.extend([_ for _ in label if len(_) > 3])
+            rst = list(set(rst))
         if rst:
             return rst
         # 挖掘结果为空时兜底策略
@@ -312,43 +320,53 @@ class SentenceKeyword:
 
 def get_keyword_graph4panda(info, **kwargs):
     # info 的格式为comment_id	group_id	text
+    # todo 计算vv的逻辑可以优化
     info_list = np2list(info)
     texts = []
     text2info = {}
-    for comment_id, group_id, text in info_list:
+    for comment_id, group_id, vv, text in info_list:
         texts.append(text)
-        text2info[text] = (comment_id, group_id)
+        if vv == 'NULL':
+            vv = 0
+        else:
+            vv = int(vv)
+        text2info[text] = (comment_id, group_id, vv)
     rst, node, rel = get_keyword_graph(texts, **kwargs)
     node_detail = []
-    for kp, score, sents in node:
+    for kp, rank_score, sents, times, score_sum in node:
+        svv = 0
         detail = []
+        for _text in text2info.keys():
+            if kp in _text:
+                svv += text2info[_text][2]
         for sent in sents:
             if sent in text2info:
                 detail.append({'text': sent, 'comment_id':text2info[sent][0], 'group_id':text2info[sent][1]})
-        node_detail.append([kp, score, detail])
+        node_detail.append([kp, rank_score, svv, detail])
     return node_detail, rel
 
 
 if __name__ == '__main__':
-    data = [
-        '纨绔的游戏，不知道正义能不能到来',
-        '严打之下，应该没有保护伞。恶魔，早点得到应有的报应。',
-        '父母什么责任？？你24小时跟着你14岁的孩子的吗？',
-        '我要当父亲别说三个了，他三家人都要去团聚[抠鼻][抠鼻]',
-        '不是有意违规',
-        '怎么就违规了'
-    ]
+    # data = [
+    #     '纨绔的游戏，不知道正义能不能到来',
+    #     '严打之下，应该没有保护伞。恶魔，早点得到应有的报应。',
+    #     '父母什么责任？？你24小时跟着你14岁的孩子的吗？',
+    #     '我要当父亲别说三个了，他三家人都要去团聚[抠鼻][抠鼻]',
+    #     '不是有意违规',
+    #     '怎么就违规了'
+    # ]
     # xx = SentenceKeyword()
     # for s in data:
     #     print(s)
     #     print(xx.get_sentence_keyword(s))
 
-    all_feature, node, relation = get_keyword_graph(data)
-    print(node)
-    print(relation)
+    # all_feature, node, relation = get_keyword_graph(data)
+    # print(node)
+    # print(relation)
 
     # SentenceKeyword.update_keyword('/Users/bytedance/Downloads/281474998307169-point_extend-拉取大量标题-查询4.csv')
 
     # data = load_excel('/Users/bytedance/PycharmProjects/textgraph/南宁杀人_mini.xlsx')
     # print(get_keyword_graph4panda(data))
     # print(get_keyword_graph4panda(data, default_keyword=True))
+    pass
